@@ -36,6 +36,10 @@
 #endif
 #endif // PQXX_HAVE_SYS_SELECT_H
 
+#ifdef PQXX_HAVE_POLL
+#include <poll.h>
+#endif
+
 #include "libpq-fe.h"
 
 #include "pqxx/binarystring"
@@ -72,18 +76,19 @@ static fd_set *const fdset_none = &emptyfd;
 #endif	// PQXX_SELECT_ACCEPTS_NULL
 
 
-
+#ifndef PQXX_HAVE_POLL
 // Concentrate stupid "old-style cast" warnings for GNU libc in one place, and
 // by using "C" linkage, perhaps silence them altogether.
 static void set_fdbit(int f, fd_set *s)
 {
   FD_SET(f, s);
 }
-
 static void clear_fdmask(fd_set *mask)
 {
   FD_ZERO(mask);
 }
+#endif
+
 }
 
 
@@ -187,7 +192,28 @@ void pqxx::connection_base::deactivate()
 }
 
 
-void pqxx::connection_base::set_variable(const string &Var, const string &Value)
+int pqxx::connection_base::protocol_version() const throw ()
+{
+#ifdef PQXX_HAVE_PQPROTOCOLVERSION
+  return m_Conn ? PQprotocolVersion(m_Conn) : 0;
+#else
+  return 0;
+#endif
+}
+
+
+int pqxx::connection_base::server_version() const throw ()
+{
+#ifdef PQXX_HAVE_PQSERVERVERSION
+  return m_Conn ? PQserverVersion(m_Conn) : 0;
+#else
+  return 0;
+#endif
+}
+
+
+void pqxx::connection_base::set_variable(const PGSTD::string &Var,
+	const PGSTD::string &Value)
 {
   if (m_Trans.get())
   {
@@ -203,13 +229,13 @@ void pqxx::connection_base::set_variable(const string &Var, const string &Value)
 }
 
 
-string pqxx::connection_base::get_variable(const string &Var)
+string pqxx::connection_base::get_variable(const PGSTD::string &Var)
 {
   return m_Trans.get() ? m_Trans.get()->get_variable(Var) : RawGetVar(Var);
 }
 
 
-string pqxx::connection_base::RawGetVar(const string &Var)
+string pqxx::connection_base::RawGetVar(const PGSTD::string &Var)
 {
   // Is this variable in our local map of set variables?
   // TODO: Is it safe to read-allocate variables in the "cache?"
@@ -338,14 +364,24 @@ void pqxx::connection_base::check_result(const result &R, const char Query[])
     if (!consume_input()) throw broken_connection(e.what());
     const int fd = sock();
     if (fd < 0) throw broken_connection(e.what());
+
+#ifdef PQXX_HAVE_POLL
+    pollfd pfd = { fd, POLLERR|POLLHUP|POLLNVAL, 0 };
+#else
     fd_set errs;
     clear_fdmask(&errs);
+#endif
+
     int sel;
     do
     {
+#ifdef PQXX_HAVE_POLL
+      sel = poll(&pfd, 1, 0);
+#else
       timeval nowait = { 0, 0 };
       set_fdbit(fd, &errs);
       sel = select(fd+1, 0, 0, &errs, &nowait);
+#endif
     } while (sel == -1 && errno == EINTR);
 
     switch (sel)
@@ -359,6 +395,7 @@ void pqxx::connection_base::check_result(const result &R, const char Query[])
       case ENOMEM:
         throw bad_alloc();
       }
+      break;
     case 0:
       break;
     case 1:
@@ -385,7 +422,8 @@ bool pqxx::connection_base::is_open() const throw ()
 }
 
 
-void pqxx::connection_base::switchnoticer(const auto_ptr<noticer> &N) throw ()
+void pqxx::connection_base::switchnoticer(const PGSTD::auto_ptr<noticer> &N)
+	throw ()
 {
   const PQnoticeProcessor old =
 	PQsetNoticeProcessor(m_Conn, pqxxNoticeCaller, N.get());
@@ -395,7 +433,7 @@ void pqxx::connection_base::switchnoticer(const auto_ptr<noticer> &N) throw ()
 
 
 auto_ptr<pqxx::noticer>
-pqxx::connection_base::set_noticer(auto_ptr<noticer> N) throw ()
+pqxx::connection_base::set_noticer(PGSTD::auto_ptr<noticer> N) throw ()
 {
   if (m_Conn)
   {
@@ -467,7 +505,7 @@ void pqxx::connection_base::process_notice(const char msg[]) throw ()
   }
 }
 
-void pqxx::connection_base::process_notice(const string &msg) throw ()
+void pqxx::connection_base::process_notice(const PGSTD::string &msg) throw ()
 {
   // Ensure that message passed to noticer ends in newline
   if (msg[msg.size()-1] == '\n')
@@ -551,7 +589,7 @@ void pqxx::connection_base::RemoveTrigger(pqxx::trigger *T) throw ()
     else
     {
       // Erase first; otherwise a notification for the same trigger may yet come
-      // in and wreak havoc.  Thanks Dragan Milenkovic. 
+      // in and wreak havoc.  Thanks Dragan Milenkovic.
       m_Triggers.erase(i);
 
       if (m_Conn && (R.second == ++R.first))
@@ -682,8 +720,9 @@ pqxx::result pqxx::connection_base::Exec(const char Query[], int Retries)
 }
 
 
-pqxx::prepare::declaration pqxx::connection_base::prepare(const string &name,
-    const string &definition)
+pqxx::prepare::declaration pqxx::connection_base::prepare(
+	const PGSTD::string &name,
+	const PGSTD::string &definition)
 {
   PSMap::iterator i = m_prepared.find(name);
   if (i != m_prepared.end())
@@ -705,7 +744,7 @@ pqxx::prepare::declaration pqxx::connection_base::prepare(const string &name,
 }
 
 
-void pqxx::connection_base::unprepare(const string &name)
+void pqxx::connection_base::unprepare(const PGSTD::string &name)
 {
   PSMap::iterator i = m_prepared.find(name);
 
@@ -721,14 +760,16 @@ void pqxx::connection_base::unprepare(const string &name)
 #ifndef PQXX_HAVE_PQEXECPREPARED
 namespace
 {
-string escape_param(const char in[], prepare::param_treatment treatment)
+string escape_param(const char in[],
+	int len,
+	prepare::param_treatment treatment)
 {
   if (!in) return "null";
-  
+
   switch (treatment)
   {
   case treat_binary:
-    return "'" + escape_binary(in) + "'";
+    return "'" + escape_binary(string(in,len)) + "'";
 
   case treat_string:
     return "'" + pqxx::internal::escape_string(in, strlen(in)) + "'";
@@ -766,7 +807,7 @@ string escape_param(const char in[], prepare::param_treatment treatment)
 
 
 pqxx::prepare::internal::prepared_def &
-pqxx::connection_base::find_prepared(const string &statement)
+pqxx::connection_base::find_prepared(const PGSTD::string &statement)
 {
   PSMap::iterator s = m_prepared.find(statement);
   if (s == m_prepared.end())
@@ -774,9 +815,10 @@ pqxx::connection_base::find_prepared(const string &statement)
   return s->second;
 }
 
-void pqxx::connection_base::prepare_param_declare(const string &statement,
-    const string &sqltype,
-    param_treatment treatment)
+void pqxx::connection_base::prepare_param_declare(
+	const PGSTD::string &statement,
+	const PGSTD::string &sqltype,
+	param_treatment treatment)
 {
   prepare::internal::prepared_def &s = find_prepared(statement);
   if (s.complete)
@@ -787,8 +829,11 @@ void pqxx::connection_base::prepare_param_declare(const string &statement,
 }
 
 
-pqxx::result pqxx::connection_base::prepared_exec(const string &statement,
+// TODO: Can we make this work with std::string instead of C-style?
+pqxx::result pqxx::connection_base::prepared_exec(
+	const PGSTD::string &statement,
 	const char *const params[],
+	const int paramlengths[],
 	int nparams)
 {
   activate();
@@ -815,7 +860,7 @@ pqxx::result pqxx::connection_base::prepared_exec(const string &statement,
     if (!s.parameters.empty())
       P << '('
 	<< separated_list(",",
-	   	s.parameters.begin(),
+		s.parameters.begin(),
 		s.parameters.end(),
 		prepare::internal::get_sqltype())
 	<< ')';
@@ -827,7 +872,18 @@ pqxx::result pqxx::connection_base::prepared_exec(const string &statement,
   }
 
 #ifdef PQXX_HAVE_PQEXECPREPARED
-  result r(PQexecPrepared(m_Conn,statement.c_str(),nparams,params,0,0,0));
+  internal::scoped_array<int> binary(nparams+1);
+  for (int i=0; i<nparams; ++i)
+    binary[i] = (s.parameters[i].treatment == treat_binary);
+  binary[nparams] = 0;
+
+  result r(PQexecPrepared(m_Conn,
+	statement.c_str(),
+	nparams,
+	params,
+	paramlengths,
+	binary.c_ptr(),
+	0));
 #else
   stringstream Q;
   if (supports(cap_prepared_statements))
@@ -838,7 +894,7 @@ pqxx::result pqxx::connection_base::prepared_exec(const string &statement,
       Q << " (";
       for (int a = 0; a < nparams; ++a)
       {
-	Q << escape_param(params[a],s.parameters[a].treatment);
+	Q << escape_param(params[a],paramlengths[a],s.parameters[a].treatment);
 	if (a < nparams-1) Q << ',';
       }
       Q << ')';
@@ -852,7 +908,9 @@ pqxx::result pqxx::connection_base::prepared_exec(const string &statement,
     for (int n = nparams-1; n >= 0; --n)
     {
       const string key = "$" + to_string(n+1),
-	           val = escape_param(params[n],s.parameters[n].treatment);
+	           val = escape_param(params[n],
+				paramlengths[n],
+				s.parameters[n].treatment);
       const string::size_type keysz = key.size();
       for (string::size_type h=S.find(key); h!=string::npos; h=S.find(key))
 	S.replace(h,keysz,val);
@@ -922,13 +980,15 @@ void pqxx::connection_base::close() throw ()
 }
 
 
-void pqxx::connection_base::RawSetVar(const string &Var, const string &Value)
+void pqxx::connection_base::RawSetVar(const PGSTD::string &Var,
+	const PGSTD::string &Value)
 {
     Exec(("SET " + Var + "=" + Value).c_str(), 0);
 }
 
 
-void pqxx::connection_base::AddVariables(const map<string,string> &Vars)
+void pqxx::connection_base::AddVariables(
+	const PGSTD::map<PGSTD::string,PGSTD::string> &Vars)
 {
   for (map<string,string>::const_iterator i=Vars.begin(); i!=Vars.end(); ++i)
     m_Vars[i->first] = i->second;
@@ -988,7 +1048,7 @@ const string theWriteTerminator = "\\.";
 #endif
 
 
-bool pqxx::connection_base::ReadCopyLine(string &Line)
+bool pqxx::connection_base::ReadCopyLine(PGSTD::string &Line)
 {
   if (!is_open())
     throw internal_error("ReadCopyLine() without connection");
@@ -1064,7 +1124,7 @@ bool pqxx::connection_base::ReadCopyLine(string &Line)
 }
 
 
-void pqxx::connection_base::WriteCopyLine(const string &Line)
+void pqxx::connection_base::WriteCopyLine(const PGSTD::string &Line)
 {
   if (!is_open())
     throw internal_error("WriteCopyLine() without connection");
@@ -1120,7 +1180,7 @@ void pqxx::connection_base::EndCopyWrite()
 }
 
 
-void pqxx::connection_base::start_exec(const string &Q)
+void pqxx::connection_base::start_exec(const PGSTD::string &Q)
 {
   activate();
   if (!PQsendQuery(m_Conn, Q.c_str())) throw runtime_error(ErrMsg());
@@ -1164,7 +1224,8 @@ string pqxx::connection_base::esc(const char str[], size_t maxlen)
 }
 
 
-string pqxx::connection_base::esc_raw(const unsigned char str[], size_t len)
+PGSTD::string pqxx::connection_base::esc_raw(const unsigned char str[],
+	size_t len)
 {
   size_t bytes = 0;
 #ifdef PQXX_HAVE_PQESCAPEBYTEACONN
@@ -1191,10 +1252,16 @@ namespace
 void wait_fd(int fd, bool forwrite=false, timeval *tv=0)
 {
   if (fd < 0) throw pqxx::broken_connection();
+
+#ifdef PQXX_HAVE_POLL
+  pollfd pfd = { fd, POLLERR|POLLHUP|POLLNVAL | (forwrite?POLLOUT:POLLIN) , 0 };
+  poll(&pfd, 1, (tv ? (tv->tv_sec*1000 + tv->tv_usec/1000) : -1));
+#else
   fd_set s;
   clear_fdmask(&s);
   set_fdbit(fd, &s);
   select(fd+1, (forwrite?fdset_none:&s), (forwrite?&s:fdset_none), &s, tv);
+#endif
 }
 } // namespace
 
@@ -1284,7 +1351,7 @@ void pqxx::connection_base::set_capability(capability c) throw ()
 }
 
 
-string pqxx::connection_base::adorn_name(const string &n)
+string pqxx::connection_base::adorn_name(const PGSTD::string &n)
 {
   const string id = to_string(++m_unique_id);
   return n.empty() ? ("x"+id) : (n+"_"+id);
