@@ -94,6 +94,12 @@ template<typename L, typename R>
 
 namespace pqxx
 {
+template<> void from_string(const char Str[], PGSTD::string &Obj, size_t len)
+{
+  Obj = string(Str, len);
+}
+
+
 template<> void from_string(const char Str[], long &Obj)
 {
   int i = 0;
@@ -103,7 +109,7 @@ template<> void from_string(const char Str[], long &Obj)
   {
     if (Str[i] != '-')
       throw runtime_error("Could not convert string to integer: '" +
-      	string(Str) + "'");
+	string(Str) + "'");
 
     for (++i; isdigit(Str[i]); ++i)
     {
@@ -136,7 +142,7 @@ template<> void from_string(const char Str[], unsigned long &Obj)
 
   if (!isdigit(Str[i]))
     throw runtime_error("Could not convert string to unsigned integer: '" +
-    	string(Str) + "'");
+	string(Str) + "'");
 
   for (result=0; isdigit(Str[i]); ++i)
   {
@@ -345,7 +351,7 @@ template<typename T> inline string to_string_fallback(T Obj)
 template<typename T> inline bool is_NaN(T Obj)
 {
     // TODO: Is this workaround for missing isnan() reliable?  Infinities?
-  return 
+  return
 #if defined(PQXX_HAVE_ISNAN)
     isnan(Obj);
 #elif defined(PQXX_HAVE_LIMITS)
@@ -587,6 +593,39 @@ void pqxx::internal::freemem_notif(pqxx::internal::pq::PGnotify *p) throw ()
 }
 
 
+pqxx::internal::refcount::refcount() :
+  m_l(this),
+  m_r(this)
+{
+}
+
+
+pqxx::internal::refcount::~refcount()
+{
+  loseref();
+}
+
+
+void pqxx::internal::refcount::makeref(refcount &rhs) throw ()
+{
+  // TODO: Make threadsafe
+  m_l = &rhs;
+  m_r = rhs.m_r;
+  m_l->m_r = m_r->m_l = this;
+}
+
+
+bool pqxx::internal::refcount::loseref() throw ()
+{
+  // TODO: Make threadsafe
+  const bool result = (m_l == this);
+  m_r->m_l = m_l;
+  m_l->m_r = m_r;
+  m_l = m_r = this;
+  return result;
+}
+
+
 string pqxx::internal::namedclass::description() const
 {
   try
@@ -626,7 +665,7 @@ void pqxx::internal::CheckUniqueUnregistration(const namedclass *New,
   {
     if (!New)
       throw logic_error("Expected to close " + Old->description() + ", "
-	  		"but got NULL pointer instead");
+			"but got NULL pointer instead");
     if (!Old)
       throw logic_error("Closed while not open: " + New->description());
     throw logic_error("Closed " + New->description() + "; "
