@@ -40,17 +40,22 @@ int main(int argc, char *argv[])
       Drop.exec(("DROP TABLE " + TableName).c_str());
       Drop.commit();
     }
-    catch (const sql_error &e)
+    catch (const undefined_table &e)
     {
       cout << "(Expected) Couldn't drop table: " << e.what() << endl
 	   << "Query was: " << e.query() << endl;
     }
+    catch (const sql_error &e)
+    {
+      cerr << "Couldn't drop table: " << e.what() << endl
+	   << "Query was: " << e.query() << endl;
+    }
 
     // Now begin new transaction to create new table & write data
     work T(C, "test5");
 
-    T.exec(("CREATE TABLE " + 
-	    TableName + 
+    T.exec(("CREATE TABLE " +
+	    TableName +
 	    "(year INTEGER, event VARCHAR)").c_str());
 
     tablewriter W(T, TableName);
@@ -76,7 +81,7 @@ int main(int argc, char *argv[])
     cout << "Writing data to " << TableName << endl;
 
     // Insert tuple of data using "begin" and "end" abstraction
-    for (int i=0; CData[i][0]; ++i) 
+    for (int i=0; CData[i][0]; ++i)
       W.insert(&CData[i][0], &CData[i][2]);
 
     // Insert tuple of data held in container
