@@ -11,7 +11,7 @@ using namespace pqxx;
 
 
 // Test program for libpqxx.  Create a table of numbers, write data to it using
-// a tablewriter back_insert_iterator, then verify the table's contents using 
+// a tablewriter back_insert_iterator, then verify the table's contents using
 // field iterators
 //
 // Usage: test083 [connect-string]
@@ -40,11 +40,16 @@ int main(int, char *argv[])
       nontransaction Drop(C, "drop_" + Table);
       Drop.exec("DROP TABLE " + Table);
     }
-    catch (const sql_error &e)
+    catch (const undefined_table &e)
     {
       cout << "(Expected) Couldn't drop table: " << e.what() << endl
 	   << "Query was: " << e.query() << endl;
     }
+    catch (const sql_error &e)
+    {
+      cerr << "Couldn't drop table: " << e.what() << endl
+	   << "Query was: " << e.query() << endl;
+    }
 
     work T(C, "test83");
     T.exec("CREATE TABLE " + Table + "(num INTEGER)");
@@ -65,7 +70,7 @@ int main(int, char *argv[])
       if (r->at(0).as(0) != (*i)[0])
 	throw logic_error("Writing numbers with tablewriter went wrong: "
 	    "expected " + to_string((*i)[0]) + ", found " + r[0].c_str());
-  
+
     T.commit();
   }
   catch (const sql_error &e)
